import React, { useState } from 'react';
import { Button, Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../components';
import { Fullscreen, Schema as SchemaIcon, Search as SearchIcon } from '@mui/icons-material';
import Schema from '../schema/panel';
import Searchbar from './search/searchbar';
import ColorMode from '../components/color-mode';
import ControlContainer from '../components/controls';

export default function DataViewer({ auth }: { auth: boolean }) {
  const [tab, setTab] = useState('Schema');
  const [showDialog, setShowDialog] = useState<boolean>(true);

  return (
    <div className="info-panel w-full h-full flex">
      <TooltipProvider delayDuration={100}>
        <div className="w-12 flex flex-col items-center justify-between">
          <div>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  type="secondary"
                  variant="ghost"
                  size="md"
                  iconComponent={<SearchIcon />}
                  onClick={() => {
                    if (!showDialog) {
                      setShowDialog(true);
                    } else if (tab === 'Search') {
                      setShowDialog(false);
                    }
                    setTab('Search');
                  }}
                  additionalClasses={tab === 'Search' ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>Search</TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  type="secondary"
                  variant="ghost"
                  size="md"
                  iconComponent={<SchemaIcon />}
                  onClick={() => {
                    if (!showDialog) {
                      setShowDialog(true);
                    } else if (tab === 'Schema') {
                      setShowDialog(false);
                    }
                    setTab('Schema');
                  }}
                  additionalClasses={tab === 'Schema' ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>Database schema</TooltipContent>
            </Tooltip>
          </div>
          <ColorMode />
        </div>
        {showDialog && (
          <div className="flex-1 border border-secondary-200 overflow-hidden">
            <div className="relative flex items-center justify-between z-[2] py-0 px-2 bg-secondary-100  border-b border-secondary-200">
              <h1 className="text-xs font-semibold text-secondary-800">{tab}</h1>
              <ControlContainer>
                {tab === 'Schema' && (
                  <Tooltip>
                    <TooltipTrigger asChild>
                      <Button type="secondary" variant="ghost" size="xs" iconComponent={<Fullscreen />} onClick={() => {}} />
                    </TooltipTrigger>
                    <TooltipContent side={'bottom'}>
                      <p>Fit to screen</p>
                    </TooltipContent>
                  </Tooltip>
                )}
                {tab === 'Search' && (
                  <Tooltip>
                    <TooltipTrigger asChild>
                      <Button type="secondary" variant="ghost" size="xs" iconComponent={<Fullscreen />} onClick={() => {}} />
                    </TooltipTrigger>
                    <TooltipContent side={'bottom'}>
                      <p>Mock icon</p>
                    </TooltipContent>
                  </Tooltip>
                )}
              </ControlContainer>
            </div>
            {tab === 'Search' && <Searchbar />}
            {tab === 'Schema' && <Schema auth={auth} />}
          </div>
        )}
      </TooltipProvider>
    </div>
  );
}
