import React from 'react';
import { Button } from '../../components';
import { Delete } from '@mui/icons-material';
import Input from '../../components/inputs';
import { VISUALIZATION_TYPES, VisualizationManager } from '../manager';

type Props = {
  manager: VisualizationManager;
};

export function ConfigPanel({ manager }: Props) {
  return (
    <div className="w-full h-full flex flex-col border">
      <div className="border-b border-secondary-200 py-2">
        <div className="flex justify-between items-center px-4 py-2">
          <span className="text-xs font-bold">Visualisation</span>
          <Button
            type="secondary"
            variant="ghost"
            size="xs"
            iconComponent={<Delete />}
            onClick={() => {
              if (manager.active) manager.deleteVisualization(manager.active);
            }}
          />
        </div>
        <div className="flex justify-between items-center px-4 py-1">
          <span className="text-xs font-normal">Type</span>
          <div className="w-36">
            <Input type="dropdown" size="xs" options={VISUALIZATION_TYPES} value={manager.active} onChange={() => {}} />
          </div>
        </div>
        <div className="flex justify-between items-center px-4 py-1">
          <span className="text-xs font-normal">Name</span>
          <input type="text" className="border rouded w-36" value={manager.active} onChange={() => {}} />
        </div>
      </div>
      {manager.active && <div className="border-b border-secondary-200 py-2">{manager.renderSettings()}</div>}
    </div>
  );
}
