import React from 'react';
import { useGraphQueryResult, useQuerybuilderGraph } from '@graphpolaris/shared/lib/data-access';
import VisualizationBar from './bar';
import { VisualizationManager } from './manager';
import { Recommender, NoData, Querying } from './screens';

export const VisualizationPanel = ({ manager }: { manager: VisualizationManager }) => {
  const query = useQuerybuilderGraph();
  const graphQueryResult = useGraphQueryResult();

  const renderContent = () => {
    if (graphQueryResult.queryingBackend) {
      return <Querying />;
    } else if (graphQueryResult.nodes.length === 0) {
      return <NoData dataAvailable={query.nodes.length > 0} />;
    } else if (manager.tabs.length === 0) {
      return <Recommender onClick={(id: string) => manager.changeActive(id)} />;
    }
    return <div className="w-full h-full">{manager.renderComponent()}</div>;
  };

  return (
    <div className="vis-panel h-full w-full">
      <VisualizationBar manager={manager} />
      <div className="overflow-y-auto" style={graphQueryResult.nodes.length === 0 ? { overflow: 'hidden' } : {}}>
        {renderContent()}
      </div>
    </div>
  );
};
