import React from 'react';
import { CompositeLayer } from 'deck.gl/typed';
import { IconLayer } from '@deck.gl/layers/typed';
import { getProperty } from '../../utlis';
import * as d3 from 'd3';
import IconOptions from './IconOptions';
import { LayerProps } from '../../Types';

// TODO: Make icons based on node property

export const IconLayerConfig = {
  attribute: '',
};

const ICON_MAPPING = {
  marker: { x: 0, y: 0, width: 128, height: 128, mask: false },
};

export class NodeIconLayer extends CompositeLayer<LayerProps> {
  static type = 'Icon';
  static layerOptions = IconLayerConfig;

  static generateLayerOptions(layer: any, updatedLayer: void, graphInfo: { [key: string]: any }, deleteLayer: void) {
    return <IconOptions layer={layer} updatedLayer={updatedLayer} graphInfo={graphInfo} deleteLayer={deleteLayer} />;
  }

  updateState({ props, oldProps, context, changeFlags }: { props: any; oldProps: any; context: any; changeFlags: any }) {
    const { graph, config } = props;
    console.log(props, oldProps, context, changeFlags);
  }

  renderLayers() {
    const { graph, config, visible } = this.props;

    return new IconLayer(
      this.getSubLayerProps({
        hidden: visible,
        data: graph.getNodes(),
        iconAtlas: 'https://raw.githubusercontent.com/visgl/deck.gl-data/master/website/icon-atlas.png',
        iconMapping: ICON_MAPPING,
        getIcon: (d: any) => 'marker',
        sizeScale: 10,
        getPosition: (d: any) => [d.attributes.long, d.attributes.lat],
        getSize: (d: any) => 5,
        getColor: (d: any) => [Math.sqrt(d.exits), 140, 0],
      })
    );
  }
}

NodeIconLayer.layerName = 'Icon';
